#
# spec file for package pango
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pango
Version:        1.54.0
Release:        1.1
Summary:        Library for Layout and Rendering of Text
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://pango.gnome.org/
Source0:        %{name}-%{version}.tar.xz
Source2:        macros.pango
Source99:       baselibs.conf

BuildRequires:  gcc-c++
BuildRequires:  help2man
BuildRequires:  meson >= 0.63.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo) >= 1.12.10
BuildRequires:  pkgconfig(fontconfig) >= 2.13
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi) >= 1.0.6
BuildRequires:  pkgconfig(glib-2.0) >= 2.62
BuildRequires:  pkgconfig(gobject-2.0) >= 2.59.2
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(harfbuzz) >= 2.6
BuildRequires:  pkgconfig(libthai) >= 0.1.9
BuildRequires:  pkgconfig(xft) >= 2.0.0
BuildRequires:  pkgconfig(xrender)

%description
Pango is a library for layout and rendering of text, with an emphasis
on internationalization. It can be used anywhere that text layout
is needed.

Pango forms the core of text and font handling for GTK+.

%package -n libpango-1_0-0
Summary:        Library for Layout and Rendering of Text
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
Obsoletes:      pango-modules < %{version}
Provides:       pango-modules = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      pango-64bit
%endif
#

%description -n libpango-1_0-0
Pango is a library for layout and rendering of text, with an emphasis
on internationalization. It can be used anywhere that text layout
is needed.

Pango forms the core of text and font handling for GTK+.

%package -n typelib-1_0-Pango-1_0
Summary:        Introspection bindings for pango, a library for text layout and rendering
Group:          System/Libraries

%description -n typelib-1_0-Pango-1_0
Pango is a library for layout and rendering of text, with an emphasis
on internationalization. It can be used anywhere that text layout
is needed.

Pango forms the core of text and font handling for GTK+.

This package provides the GObject Introspection bindings for Pango.

%package tools
Summary:        Tools for pango, a library for text layout and rendering
Group:          System/Libraries
# for the 'gm' command used by 'pango-view --backend=ft2'
Recommends:     GraphicsMagick

%description tools
Pango is a library for layout and rendering of text, with an emphasis
on internationalization. It can be used anywhere that text layout
is needed.

Pango forms the core of text and font handling for GTK+.

%package devel
Summary:        Development files for pango, a library for text layout and rendering
Group:          Development/Libraries/GNOME
Requires:       libpango-1_0-0 = %{version}
Requires:       typelib-1_0-Pango-1_0 = %{version}
Provides:       pango-doc = %{version}
Obsoletes:      pango-doc < %{version}
# bug437293
%ifarch ppc64
Obsoletes:      pango-devel-64bit
%endif

%description devel
Pango is a library for layout and rendering of text, with an emphasis
on internationalization. It can be used anywhere that text layout
is needed.

Pango forms the core of text and font handling for GTK+.

This package contains all necessary include files and libraries needed
to develop applications that require these.

%prep
%autosetup -p1

%build
%meson \
	-Dintrospection=enabled \
	%{nil}
%meson_build

%install
%meson_install

# Install rpm macros
mkdir -p %{buildroot}%_rpmmacrodir
cp %{SOURCE2} %{buildroot}%_rpmmacrodir

%ldconfig_scriptlets -n libpango-1_0-0

%files -n libpango-1_0-0
%license COPYING
%doc NEWS README.md
%{_libdir}/libpango-1.0.so.*
%{_libdir}/libpangocairo-1.0.so.*
%{_libdir}/libpangoft2-1.0.so.*
%{_libdir}/libpangoxft-1.0.so.*

%files -n typelib-1_0-Pango-1_0
%{_libdir}/girepository-1.0/Pango-1.0.typelib
%{_libdir}/girepository-1.0/PangoCairo-1.0.typelib
%{_libdir}/girepository-1.0/PangoFT2-1.0.typelib
%{_libdir}/girepository-1.0/PangoXft-1.0.typelib
%{_libdir}/girepository-1.0/PangoFc-1.0.typelib
%{_libdir}/girepository-1.0/PangoOT-1.0.typelib

%files tools
%{_bindir}/pango-list
%{_bindir}/pango-segmentation
%{_bindir}/pango-view
%{_mandir}/man1/pango-view.1%{ext_man}

%files devel
%doc CODING_STYLE.md THANKS
%_rpmmacrodir/macros.pango
%{_includedir}/pango-1.0/
%{_libdir}/libpango-1.0.so
%{_libdir}/libpangocairo-1.0.so
%{_libdir}/libpangoft2-1.0.so
%{_libdir}/libpangoxft-1.0.so
%{_libdir}/pkgconfig/pango.pc
%{_libdir}/pkgconfig/pangocairo.pc
%{_libdir}/pkgconfig/pangoft2.pc
%{_libdir}/pkgconfig/pangoxft.pc
%{_libdir}/pkgconfig/pangofc.pc
%{_libdir}/pkgconfig/pangoot.pc
%{_datadir}/gir-1.0/Pango-1.0.gir
%{_datadir}/gir-1.0/PangoCairo-1.0.gir
%{_datadir}/gir-1.0/PangoFT2-1.0.gir
%{_datadir}/gir-1.0/PangoFc-1.0.gir
%{_datadir}/gir-1.0/PangoOT-1.0.gir
%{_datadir}/gir-1.0/PangoXft-1.0.gir

%changelog
* Mon Jun 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.54.0:
  + Build fixes.
  + Memory leak fixes.
  + Drop the install-tests build option.
  + Add build-examples and build-tests build options.
  + Require meson 0.63.
  + Add pango_item_get_char_offset.
  + Update to Unicode 15.1.
  + Fix wrong use of GWeakRef, leading to crashes.
- Drop -Dinstall-tests meson parameter: no longer supported.
* Thu Apr  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.52.2:
  + coretext: Implement reload_font.
  + coretext: Use Menlo instead of Courier for monospace.
  + win32: Avoid a double free.
  + Update to Unicode 15.1.
  + Simplify hexbox drawing.
- Changes from version 1.52.1:
  + Fix hexbox drawing.
* Sun Mar 31 2024 Michael Pujos <pujos.michael@gmail.com>
- added GraphicsMagick package as Recommends. The invocation of
  pango-view with the ft2 backend requires the gm command found in
  that package
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.52.0:
  + Add pango_font_map_reload_font.
  + Improve formatting of font sizes.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.51.2:
  + Use single fontconfig thread.
  + Fix problems with spaces at line ends.
  + Allow custom fonts on Windows.
  + pango-viewer: Fix hint-metrics options.
  + Pangofont: Add properties.
* Sat Aug 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.51.1:
  + itemize: Improve script itemization
  + build: Check for cairo DWrite dependency
  + win32: Fix various issues and crashes
  + layout: Add a missing switch case
* Thu Mar  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.14:
  + Fix underline thickness in scaled contexts.
* Tue Feb 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.13:
  + win32:
  - Add back fallback for empty fontsets
  - Improve DirectWrite support
  + Fix word segmentation for Japanese
  + Don't set backspace-deletes-char for math symbols
  + coretext: Fix a crash
  + cairo: Apply metrics hinting to underlines too
  + Treat COLRv1 fonts as color fonts
* Wed Nov 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.50.12:
  + Fix weight conversion on MacOS.
  + Update to Unicode 15.
  + Some introspection annotation fixes.
  + Improve PangoAttrList serialization.
  + Fix char offset calculatiosn in multi-paragraph layouts.
* Tue Oct  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.11:
  + Don't crash for lack of fonts.
  + Avoid a crash in shaping.
- Drop 639.patch: Fixed upstream.
* Sun Sep 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 639.patch: layout: Fix crash when no font is installed.
* Fri Sep 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.10:
  + Avoid some unnecessary strdups.
  + Fix line height computations with a non-trivial CTM.
* Wed Aug 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.9:
  + Apply show flags to line separators.
  + Fix a thread-safety problem.
* Sun Jul  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.8:
  + Add some properties to fontmap and family.
  + Fix handling of ligature carets in mixed directions.
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.50.7:
  + coretext: Fix the build.
  + editing: Fix moving across paragraph boundaries in rtl.
  + layout: Try harder to survive without fonts.
  + Windows:
  - Register a sans-serif font.
  - Try harder to load a font.
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.6:
  + Drop hb-glib dependency.
  + Fix test font configuration.
  + Maintain order in pango_attr_list_change.
  + Fix a use-after-free in pango_attr_list_change.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.5:
  + Fix compiler warnings.
  + Enable cairo by default.
  + pango-view: Show more baselines.
  + layout: Handle baselines.
- Use ldconfig_scriptlets macro for post(un) handling.
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.4:
  + Tweak synthetic space size.
  + itemize: Try harder to avoid NULL fonts.
  + docs: Some additions.
  + Pass synthetic slant to harfbuzz.
  + Make sloped carets work with uneven scales.
  + Fix serialiation on arm.
  + Avoid an uninitialized variable warning.
  + Reinstate previous behavior of pango_attr_list_splice.
  + Deprecated pango_coverage_ref/unref.
  + Fix serialization on non-glibc systems.
  + Fix allow-breaks handling.
* Thu Dec 23 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.3:
  + pango-view: Add --serialize-to option for easy bug reporting.
  + Revert a transformation change that broke metrics for vertical
    text.
  + Handle fonts without space glyph (such as icon fonts) better.
  + Fix some corner cases of line width accounting.
  + Fix line height with emulated Small Caps.
* Thu Dec 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.2:
  + Fix a problem with font fallback for Arabic.
  + Fix handling of fonts without a space glyph.
  + Various documentation improvements.
  + Fix build issues.
* Sat Dec 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.1:
  + Fix a crash in tab handling.
  + Fix tab positioning without line wrapping.
  + Fix an assertion failure found by fuzzing.
  + Make underlines work again for broken fonts.
* Fri Dec  3 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.50.0:
  + Fix glyph placement in gravity east
  + Fix line heights in improper gravities
  + Only shown selected ignorables with nicks
  + Support tab alignments other than left
  + Support custom decimal points on decimal tabs
  + Fix a pango-view crash
  + Optimize handling of many tabs
  + Drop json-glib dependency
- Drop pkgconfig(json-glib-1.0) BuildRequires, no longer needed.
* Sat Nov 27 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.49.4:
  + Require fontconfig 2.13
  + Require harfbuzz 2.6
  + Many fixes to line breaking accuracy
  + coretext: Correctly clamp text weights at min/max values
  + Add serialization api for PangoLayout, PangoFont and
    PangoAttrList
  + Require json-glib
  + tests:
  - Use serialized layouts for test cases
  - Include fonts in git
  + pango-view: Accept serialized layouts
  + Fix a rounding problem with font metrics
  + Fix visible space display using ␣
- Changes from version 1.49.3:
  + Fix hinting of glyph metrics
  + Fix logical glyph extents in vertical gravities
  + Visualize more default-ignorable glyphs
  + Fix advance widths in transformed contexts
  + Implement Small Caps and other casing variations
- Changes from version 1.49.2:
  + Update Unicode data to Unicode 14
  + Fix underlining of spaces
  + Round font metrics when appropriate
  + Fix some corner cases of cursor positioning
  + Handle Catalan middle-dot in text segmentation
- Changes from version 1.49.1:
  + Only recompute log attrs when needed
  + Validate log attrs
  + Fix conformance issues in Thai and Indic linebreaking
  + Add pango_attr_break to support customizing line and word
    breaks
  + Add font-dependent baseline shifts and sizing for super- and
    subscripts
  + Improve hyphenation support
  + pango-view:
  - Visualize caret positions and slopes
  - Show glyph rects
  - Make --annotate easier to use
  + Add pango_layout_get_caret_pos to support sloped carets
  + Improve caret positioning for ligatures
  + Better under- and overline placement
  + layout:
  - Allocate a bit less
  - Fix cluster extents with rise
  + Add pango_layout_iter_get_run_baseline
  + Add pango_glyph_string_index_to_x_full
  + coretext: Set size on font descriptions
  + Add color information to PangoGlyphVisAttr
- Changes from version 1.49.0:
  + Require fribidi 1.0.6
  + Fix threadsafety issues with Thai
  + Fix a rounding problem on i386
  + Fix font choice for ellipsis
  + New api:
  - pango_font_get_languages
  - Introspection helpers for attributes
  + Ignore width in horizontal context when itemizing
  + markup:
  - Allow specifying size and rise in points
  - Allow specifying size as percentage
  + Rewrite pango_layout_move_cursor_visually
  + Add a line-height attribute and make logical line extents
    respect it
  + Add pango_justify_last_line
  + Add pango_shape_item
  + Add a text-transform attribute and implement it
  + Clean up fribidi api usage
  + Fix a bug in the gravity data table
  + pango-view: Improve the --annotate option
  + Fix a possible crash in rendering strikethroughs
- Add pkgconfig(json-glib-1.0) BuildRequires, new dependency.
* Sun Sep 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.10:
  + Fix a crash in strikethrough drawing.
  + pango-view:
  - Support antialiasing freetype.
  - Use GraphicsMagick.
* Wed Aug 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.9:
  + Don't require a newly attached buffer to apply state.
  + Fix upside-down Xshape surface with EGLstream.
  + Misc. bug fixes and cleanups.
  + Updated translations.
* Thu Aug 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.8:
  + Rename git `master` branch to `main`
  + Fix threadsafety issues with Thai
  + Fix a rounding problem on i386
  + Fix font choice for ellipsis
  + Fix a crash if no fonts are found.
- Drop 3ff6365.patch: Upstream have made various changes to the
  offending commit.
* Tue Jul 13 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add 3ff6365.patch, reverse applied: fix build of e.g. g-c-c. This
  commit introduced a requirement to run X.
* Mon Jul  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.7:
  + Fix a thread-safety issue in fontmap initialization.
  + Small documentation improvements.
* Tue Jun 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.6:
  + Avoid attribute index overflow.
  + Add a new pango-segmentation utility.
  + Documentation cleanups and fixes.
  + Update script property data for gravity.
  + Bring back careful glyph position rounding.
  + Add a few missing bidi types.
  + Add more tests.
* Tue May 18 2021 Michael Gorse <mgorse@suse.com>
- Update to version 1.48.5:
  + Only initialize fontconfig once.
  + Add missing deprecation notices.
  + Add some missing apis to the markup docs.
  + Speed up Emoji classification.
  + Fix hangs and memory leaks.
  + Don't insert hyphens at word boundaries.
  + Handle empty lines better.
  + Avoid width fluctuations with ellipsized text.
  + Add a utility to show text segmentation.
* Sat Apr 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.48.4:
  + Include docs in the dist tarball.
  + Include gi-docgen in the dist tarball, too.
  + win32: Fix 'Cursive' fallback.
  + Fix placement of marks in vertical text.
  + Cache metrics for the current font.
  + Improve letterspacing with combining marks.
* Wed Mar 17 2021 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.48.3:
  + Miscellaneous introspection fixes
  + Make pango_attr_list_splice clip inserted attrbiutes
  + Do costly fontconfig calls in threads
  + markup: Fix issues with accel handling
  + docs: Convert docs to use gi-docgen
  + Fix build against harfbuzz < 2.6
- Disable gtk-doc for now since upstream have moved to gi-docgen and it is
  not in Factory yet
* Thu Feb 11 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.2:
  + Fix memory leaks reported by asan
  + Avoid overflow in pango_attr_list_update
  + Add a valgrind suppression file
  + Make tests more robust
  + Fix pango_font_describe for Emoji fonts
* Fri Jan 22 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.48.1:
  + Fix itemization of multi-paragraph layouts.
  + Fix a few memory leaks.
  + Fix glyph origins in vertical layout.
* Mon Nov  9 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.48.0:
  + docs: Clarify use of PangoAnalysis in shaping.
  + fontconfig: Make pango_font_family_get_face more reliable.
  + introspection: Fix use of PangoFcSubstituteFunc.
  + introspection: Skip fontconfig types.
  + build: Use yielding meson feature for introspection.
- Changes from version 1.47.0:
  + Add pango_language_get_preferred.
  + Add pango_fc_font_get_languages.
  + Sort faces of a family by slant and weight.
- Replace -Dintrospection=true meson parameter with
  - Dintrospection=enabled, following upstream changes.
* Sat Sep 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.46.2:
  + Fix pango_win32_font_map_load_font with falback families.
  + Fix an assertion in pango_language_get_scripts.
  + Fix a crash in get_items_log_attrs.
  + Fix attribute iterators with overlapping attributes.
  + Fix rendering of Emoji keycap sequences.
  + ci: Run the testsuite under asan and fix all reported issues.
  + build: Make libthai, cairo, xft, fontconfig, freetype
    dependencies meson features.
* Thu Aug 20 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.46.1:
  + Revert an unintentional PangoRenderer abi break in 1.46.0.
  + Various small fixes.
* Tue Aug 11 2020 bjorn.lie@gmail.com
- Update to version 1.46.0:
  + Undo a recent change
  + test-break: Add a legend
  + test-break: Improve output
  + Adjust "Since" tags to refer to 1.46
- Changes from version 1.45.5:
  + Fix g-i annotation of pango_parse_color_with_alpha and add since tag
  + Bump the version
  + tests: Add tests for pango_parse_color_with_alpha
  + Export pango_parse_color_with_alpha
  + pango-color: Tweak semantics of _pango_parse_color_with_alpha
- Changes from version 1.45.4:
  + testsuite: Don't use g_test_skip
  + Add a reproducer for a pidgin crash
  + layout: Avoid a crash with short strings
  + Remove hb-glib use
  + Fix a few memory leaks in tests
  + Initialise out arguments
  + pangocoretext: Fix Cairo scaling
  + fcfontmap: Always reject unsupported font formats
  + pango-attributes.c: Fix on older compilers
* Tue Jun 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.45.3:
  + Fix pango_attr_list_change
  + Fix crashes with empty attribute lists
  + Fix several crashes in gtk2 applications
  + Revert an unintentional introspection API change
  + Include HarfBuzz when igenerating introspection data
  + Undo PangoFontsetSimple deprecation
  + Annotation fixes for various apis
  + Add api to compare attribute lists
  + Update data tables to Unicode 13.0
  + Various test improvements
  + Require GLib 2.60
  + Some new font enumeration apis:
    pango_font_map_get_family
    pango_font_family_get_face
    pango_font_face_get_family
    pango_font_get_face
  + Support for line-wide underlines
  + Support for overlines
* Wed Nov 27 2019 dimstar@opensuse.org
- Update to version 1.44.7+11:
  * Add a test for ellipsis shaping
  * Use shape flags for ellipsis
  * test-shape: Cosmetics
* Sat Nov  2 2019 bjorn.lie@gmail.com
- Update to version 1.44.7+8:
  + Undo fontset deprecations.
  + Adjust expected test outputs.
  + Fix ItemProperties handling.
  + Don't treat rise as a no-shape attribute.
  + Drop an unused ItemProperties use.
  + Go back to ignoring underlines for itemization.
  + fc: remove another assertion that might trigger.
- Switch to using pango 1.44 stable git branch.
* Fri Oct 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.7:
  + Fix tests without libthai.
  + Small speedup to Emoji iteration.
  + Bring back PangoFontsetSimple (pygtk bind it).
* Fri Oct 11 2019 bjorn.lie@gmail.com
- Switch to git-checkout via source service, explicit tag. Upstream
  tarball is borked.
* Sat Sep 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Modernize spec, prepare for possible spliting of package.
* Tue Sep  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.6:
  + docs: Fix symbol indices.
  + Fix Thai line breaking.
  + Re-add symbols needed by some bindings.
  + Don't insert hyphens for some languages.
  + Fix a crash with hyphenation.
* Wed Aug 14 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.5:
  + Revert a broken change (causing crashes on OS X).
* Tue Aug 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.4:
  + Add an insert-hyphens attribute.
  + Reinstate the return type of pango_fc_font_lock_face.
  + Fix a problem with ellipses getting the wrong font.
  + fc: Improve filtering by font format.
  + Re-add PangoFcFont to public headers.
  + Install PangoFc and PangoOT introspection files.
  + Fix ink rectangles to have positive height.
  + Fix mark positioning.
  + Switch to using harfbuzz for metrics.
* Sun Aug  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.3:
  + Install pango-ot headers.
  + Make subpixel positioning optional.
  + fc: Ignore fonts with unsupported formats.
* Sat Aug  3 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.2:
  + Disable ligatures when letterspacing.
  + Set design coords on hb_font_t.
  + Expose more font options in pango-view.
  + OS X: Make 'system-ui' font work.
  + Keep deprecated pango-fc apis in headers.
  + Make hex boxes work, always.
  + introspection:
  - Various build fixes.
  - Add PangoPT, PangoFT2 namespaces.
  + layout: Make the new line-spacing opt-in.
* Mon Jul 29 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.1:
  + Fix a crash with allow_break attributes.
  + Fix Emoji spacing.
  + Fix up includes and pkg-config requires.
  + Correct some cases for hyphen insertion.
* Sat Jul 27 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.44.0:
  + Use harfbuzz for shaping on all platforms.
  + Add a getter for hb_font_t.
  + Make PangoCoverage a GObject.
  + Add a pango_tailor_break api.
  + font metrics: Add line height.
  + layout:
  - Support line spacing.
  - Draw hyphens for line breaks.
  + Add an attribute to suppress line breaking.
  + cairo: Don't render hex boxes for space.
  + Add an attribute to show invisible characters.
  + Stop quantizing glyph positions.
  + Add tests for itemization and line breaking.
  + Remove language and shape engine remnants.
  + Rename meson options: gtk_doc, introspection.
  + Require GLib 2.59.2.
  + Require Harfbuzz 2.0.
* Wed May  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Move RPM macros to %%_rpmmacrodir.
* Thu Jan  3 2019 bjorn.lie@gmail.com
- Update to version 1.43.0:
  + Drop autotools.
  + Drop Visual Studio build.
  + Build with meson everywhere.
  + Update Emoji tables for Unicode 11.
  + Update test data for Unicode 11.
  + Fix a crash with Thai breaking.
  + Fix a crash with font variations.
  + Deprecate bidi apis in favor of fribidi.
  + Add a variable font family api.
  + Improve font fallback handling on win32.
* Mon Aug 20 2018 bjorn.lie@gmail.com
- Update to version 1.42.4:
  + Prevent an assertion with invalid Unicode sequences.
  + Fix build failure in C89 mode.
  + Fix build failure on Mac OS X 10.5 and earlier.
- Drop pango-emoji-bsc1103877.patch: Fixed upstream.
* Sat Aug 18 2018 sreeves@suse.com
- Add pango-emoji-bsc1103877.patch: Fix denial of service
  when parsing emoji (bsc#1103877, CVE-2018-15120)
* Mon Jul 30 2018 bjorn.lie@gmail.com
- Update to version 1.42.3:
  + Fix handling of font lists on OS X.
  + Fix a memory leak.
* Thu Jul 19 2018 bjorn.lie@gmail.com
- Update to version 1.42.2:
  + Require harfbuzz 1.4.2.
  + Restore scaling of CoreText fonts.
  + Speed up font face enumeration.
  + Add a pango-list utility.
- Drop pango-use-non_deprecated-libthai-API.patch: Fixed upstream.
* Tue Apr 24 2018 bjorn.lie@gmail.com
- Add pango-use-non_deprecated-libthai-API.patch: Use
  non-deprecated libthai API when available.
- Pass explicit gir=true to meson, ensure we build introspection
  support.
* Sat Apr  7 2018 bjorn.lie@gmail.com
- Update to version 1.42.1:
  + Fix meson build, in particular on Windows (bgo#783274,
    bgo#795012).
  + Add an Emoji font family on Windows, using Segoe UI
    (bgo#794705).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 1.42.0:
  + No changes.
* Fri Mar  9 2018 jengelh@inai.de
- Update summaries.
* Fri Feb 16 2018 luc14n0@linuxmail.org
- Update to version 1.41.1:
  + Avoid UTF-32 conversion for fribidi.
  + Use external fribidi and drop mini-fribidi.
  + Only enable freetype if fontconfig is available.
- Add pkgconfig(fribidi) BuildRequires: new dependency.
* Thu Jan 11 2018 luc14n0@linuxmail.org
- Update to version 1.41.0:
  + Fix up font options from cairo (bgo#790747).
  + Add support for font variations.
  + Fix compiler warnings (bgo#792231).
* Fri Nov 17 2017 luc14n0@linuxmail.org
- Update to version 1.40.14:
  + Fix char break problem introduced in 1.40.13 (bgo#789625).
  + Add tests for char breaking.
* Sat Oct 28 2017 badshah400@gmail.com
- Update to version 1.40.13:
  + Some performance improvements (bgo#788643).
  + Update pango_default_break for line breaks (bgo#788115).
  + Fix an introspection warning (bgo#781857).
* Mon Sep  4 2017 zaitor@opensuse.org
- Update to version 1.40.12:
  + Fix pango_default_break for sentence start/end (bgo#785978).
  + Fix multilib issue in pango-enum-types.h (bgo#786887).
- Drop pango-fix-default-break-function.patch: Fixed upstream.
* Thu Aug 31 2017 pmonrealgonzalez@suse.com
- Add pango-fix-default-break-function.patch: Fix
  pango_default_break function for sentence start/end (bgo#785978).
* Sat Aug 19 2017 zaitor@opensuse.org
- Update to version 1.40.11:
  + Fix backspacing for more Emoji sequences.
  + Make tests run faster.
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 1.40.10:
  + Update Emoji data to version 5.
  + Apply gravity across spans in markup (bgo#784243).
  + Support variation selectors for shaping.
  + CoreText: Rely on CGFont for scaling (bgo#782393).
  + Fix grapheme breaks and backspacing for Emoji.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Add help2man BuildRequires, needed to build manpages.
- Minor spec file cleanup.
* Wed Aug  9 2017 zaitor@opensuse.org
- Update to version 1.40.9:
  + Build and dist fixes.
  + Fix build on Windows with MSVC (bgo#783274).
* Mon Aug  7 2017 zaitor@opensuse.org
- Update to version 1.40.8:
  + Support emoji sequences in boundary determination.
  + Choose emoji font for color emoji.
* Tue Jul 18 2017 zaitor@opensuse.org
- Update to version 1.40.7:
  + Some fixes for meson build support.
  + Don't change fonts for variation selectors (bgo#781123).
  + Fix some bugs in the libthai glue layer.
  + Pass text along when calling into cairo (bgo#784394).
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 1.40.6:
  + Don't use deprecated harfbuzz api.
  + Correctly implement min-required/max-allowed support.
  + Avoid compiler warnings.
  + Drop -uninstalled.pd files.
  + Add support for building with meson.
* Mon Apr 10 2017 zaitor@opensuse.org
- Update to version 1.40.5:
  + Add missing introspection annotations (bgo#778663).
  + Fix line-end handling in pango_read_line (bgo#778816).
  + Make alpha attribute work without color (bgo#773767).
  + win32: Enable rendering colored texti and underlines
    (bgo#768779).
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 1.40.4:
  + Fix introspection annotation of pango_lkayout_get_size
    (bgo#779232).
  + Fix some Coverity findings: bgo#778601, bgo#778602, bgo#778654,
    bgo#778656.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 1.40.3:
  + Fix export of pango_cairo_win32_font_map_get_type (bgo#771004).
  + Fix build on OS X (bgo#770729).
* Mon Aug 29 2016 dimstar@opensuse.org
- Update to version 1.40.2:
  + Improve introspection builds in msvc (bgo#764984).
  + Properly handle UTF32 chars in coretext.
  + Add rebeccapurple to list of colors.
  + Correct font weight mapping in coretext (bgo#766148).
  + Use version macros for exports (bgo#767587).
* Wed Aug  3 2016 hpj@suse.com
- Make libpango obsolete/provide pango-modules bsc#978972. Change
  by idonmez@suse.com.
* Tue Apr 12 2016 zaitor@opensuse.org
- Update to version 1.40.1 (Fate#318572):
  + Use $PKG_CONFIG consistently (bgo#764191).
  + Fix a PangoWin32FontMap memory leak (bgo#764089).
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 1.40.0:
  + Fix typos.
  + Don't treat OGHAM SPACE MARK as whitespace.
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 1.39.0:
  + Update PangoScript to Unicode 8.0.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 1.38.1:
  + Require Harfbuzz 0.9.30.
  + Fix make check with --enable-debug=no.
  + Win32 build fixes.
* Fri Oct  9 2015 dimstar@opensuse.org
- Drop pango-tools requirement from libpango-1_0-0: as there are no
  modules supported, there is also no querymodules call in the
  post scriptlet (also adjust baselibs.conf; do no longer build
  pango-tools-32bit, as it would be empty).
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 1.38.0:
  + No changes.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 1.37.5:
  + Small optimizations.
* Wed Sep  2 2015 zaitor@opensuse.org
- Update to version 1.37.4:
  + Use grapheme boundaries in justification.
  + Support coloring marks and bases independently (bgo#541608).
  + Fix a crash (bgo#753167).
  + Make Thai and Arabic support thread-safe.
  + Fix justification.
* Sat Aug 15 2015 zaitor@opensuse.org
- Update to version 1.37.3:
  + Fix pango_glyph_item_iter_prev.
  + Add alpha attributes.
  + Add support for alpha in markup.
* Wed Jul 22 2015 zaitor@opensuse.org
- Update to version 1.37.2:
  + Don't use hb_glib_get_unicode_funcs.
  + Warning fixes.
* Wed Jun 24 2015 zaitor@opensuse.org
- Update to version 1.37.1:
  + Add attributes for OpenType font features (bgo#738505).
  + CoreText: locale handling improvements (bgo#750017).
  + Fix ellipsization with line space (bgo#750383).
  + Fix issues with hex boxes (bgo#750463).
* Thu May 28 2015 dimstar@opensuse.org
- Update to version 1.37.0:
  + Pango modules, engines, and config have been removed
    (bgo#733882).
  + Added pango_fc_font_map_config_changed() (bgo#748767).
  + Added pango_fc_font_map_[sg]et_config() (bgo#547671).
  + Added pango_matrix_get_font_scale_factors.
  + Lot of API has been deprecated.
  + Fix CoreText font fallback.
  + General build fixes.
  + Win32 build fixes.
- Clean up scriptlets: as modules support no longer exist, there
  is no need for querymodules anymore. Change the existing macros
  in macros.pango to be dummy placeholders (to not break other
  packages referencing them) (bnc#885294).
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in post script
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 1.36.8:
  + Make tests not fail on build.gnome.org.
* Sun Sep  7 2014 zaitor@opensuse.org
- Update to version 1.36.7:
  + Add tests for pango markup.
  + Add tests for PangoLayout.
  + Add an analysis flag for ellipsis (bgo#735719).
  + Treat attributes in ellipsis better (bgo#735732).
* Sat Aug 16 2014 dimstar@opensuse.org
- Update to version 1.36.6:
  + Cope with lack of LC_CTYPE (bgo#732276).
  + Prevent harfbuzz from using replacement char.
  + Don't force static builds on win32 (bgo#733137).
  + Allow backend selection via PANGOCAIRO_BACKEND.
  + Support more font weights (bgo#733764).
  + Fix vertical positioning on win32.
  + Don't break in the middle of jamo (bgo#705727).
* Wed Aug  6 2014 tyang@suse.com
- Get rid of files using the old SUSE spelling (bnc#889024).
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 1.36.5:
  + Lower the harfbuzz requirement.
- Changes from version 1.36.4:
  + Improve thread-safety on Windows (bgo#695913).
  + Add missing annotations (bgo#729840).
  + Update PangoWeight documentation.
  + Require harfbuzz 0.9.29.
* Tue Mar 18 2014 dimstar@opensuse.org
- Update to version 1.36.3:
  + Fix builddir != srdir builds.
  + Avoid a crash when FT_Face is NULL (bgo#724006).
  + Win32 build fixes.
  + Update pango_color_parse docs (bgo#711061).
* Sun Feb 23 2014 zaitor@opensuse.org
- Pass --with-cairo to configure, to ensure we build the cairo
  backend.
* Wed Feb 19 2014 sbrabec@suse.cz
- Check for libpango instead of pango directory in pango-tools
  %%post (bnc#864561).
- Package modules.cache (bnc#864561#c3).
- Fix location of pango.modules.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 1.36.2:
  + Win32 build fixes.
  + Fix a possible strtol(NULL) (bgo#719549).
  + Fix --with-included-modules.
  + Fix a FPE in pango_layout_iter_get_char_extents (bgo#720379).
  + Use 96 dpi for CoreText by default.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 1.36.1 (bnc#849913):
  + Handle scaling absolute font sizes (bgo#708778).
  + Small documentation fixes.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 1.36.0:
  + Remove a useless test (bgo#707131).
  + Never return NULL from pango_layout_get_test (bgo#707659).
  + Correct an annotation (bgo#707874).
  + Fix gravity map (bgo#708432).
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 1.35.3:
  + Compiler warnings about strict aliasing (bgo#703995).
  + Getting rid of the arbitrary MAX_SIZE for font (bgo#707131).
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 1.35.2:
  + Bypass line reordering in some cases (bgo#705007).
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 1.35.0:
  + Requires cairo 1.12.10.
  + Add a --with-cairo option.
  + Handle invalid utf8 better (bgo#700577).
  + Install some tests.
  + Don't change fonts for space (bgo#701652).
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 1.34.1:
  + bgo#696238: PangoAttrFilterFunc vs pango_attr_list_filter docs.
  + Update win32/CoreText shaper signature.
  + Fix CoreText scaling (again).
  + Align word breaking with newer Unicode specs.
* Fri Mar 29 2013 dimstar@opensuse.org
- bnc#792646, bnc#803529#c1: Change requires pango-tools in
  baselibs.conf to prereq in order to:
  + Match the behavior of the native lib in the .spec file, where
    we use (Requires(post).
  + Ensure the right version of pango-tools is installed when the
    post script is being executed.
* Tue Mar 26 2013 zaitor@opensuse.org
- Update to version 1.34.0:
  + No changes.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 1.33.9:
  + Port PangoWin32 to use GWeakRef.
  + Use G_DEFINE_TYPE in pangowin32-fontmap (bgo#682846).
  + Fix scale in pangocairo-threads test.
  + Misc Win32 build fixes.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 1.33.8:
  + Bugs fixed: bgo#694095, bgo#668154, bgo#694626, bgo#694626,
    bgo#694830, bgo#694918, bgo#694882.
* Mon Feb  4 2013 dimstar@opensuse.org
- Update to version 1.33.7:
  + Allow enabling font features through fontconfig snipplets.
  + Fix an infinite loop when starting Inkscape.
* Mon Jan 14 2013 dimstar@opensuse.org
- Update to version 1.32.6:
  + Make pango threadsafe.
  + Pass down BOT/EOT flags to HarfBuzz.
  + Broken relocation of modules (bgo#690279).
  + Build with automake-1.13 broken (bgo#691263).
* Mon Jan 14 2013 dimstar@opensuse.org
- Require at least pango 1.31.1 for the post scriptlets to work.
  This helps for dist upgrades from openSUSE 12.2, where
  pango-querymodules did not yet know the --update-cache parameter.
  Depending on the (random) installation order during zypper dup,
  the post scriptlet of libpango-1_0-0 might execute
  pango-querymodules --update-cache, but not yet have the new tools
  installed yet (bnc#792646) (same change in baselibs.conf).
* Wed Dec 19 2012 dimstar@opensuse.org
- Update to version 1.32.5:
  + Fix build failures (bgo#689864).
  + Other bugs fixed: bgo#689882, bgo#686512, bgo#690081,
    bgo#679299, bgo#689843.
* Mon Dec 10 2012 dimstar@opensuse.org
- Update to version 1.32.4:
  + Require harfbuzz 0.9.9.
  + Add serials tracking changes in PangoFontMap/PangoContext/
    PangoLayout (bgo#340066).
  + Automatically relayout PangoLayout if PangoContext has changed.
  + Fix rendering of rotated frames.
  + Remove Thai/Lao Prepend/Extend properties (bgo#576156).
  + Fix grapheme properties of joiner / nonjoiner.
  + Fix grapheme properties of U+FFxx range.
  + Fix line break of surrogate characters.
  + Fix grapheme boundaries of surrogates and unassigned default
    ignorables.
  + Update bidi tables to Unicode 6.2.0.
  + Use -Bsymbolic-functions by default if available (bgo#689648).
  + Fix Win32 and CoreText cairo backends to take cairo CTM into
    account.
* Tue Dec  4 2012 vuntz@opensuse.org
- Update to version 1.32.3:
  + Make gobject-introspection PANGO_GLYPH happy
  + Provide a phony define for LANGUAGE
  + Adjust to harfbuzz 0.97 API
* Wed Nov 21 2012 dimstar@opensuse.org
- Do not provide typelib-1_0-Pango-1_0-32bit (baselibs.conf): this
  only results in a big mess of duplicate provides. Adding
  ($HOSTTYPE) to the typelib() symbols does not work, as we'd
  otherwise no longer be able to use them against noarch packages.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 1.32.2:
  + Fix load_fontset() for Win32 backend (bgo#685021).
  + pango-viewer: Flush cairo surface when done.
  + Xft: Fix a deadlock on display close (bgo#687470)
  + Add missing colors from the web palette.
  + Rename configure.in to configure.ac.
* Wed Oct 24 2012 jengelh@inai.de
- Make pango-devel-32bit available on all archs (baselibs.conf).
- Remove redundant tags/sections from specfile.
* Fri Sep 28 2012 vuntz@opensuse.org
- Update to version 1.32.1:
  + Fixup grapheme clusters, cause of crashes (bgo#684959)
* Wed Sep 26 2012 zaitor@opensuse.org
- Update to version 1.32.0:
  + Add a --without-xfg configure option.
  + Add pango_shape_full().
* Sat Sep 22 2012 dimstar@opensuse.org
- Update to version 1.31.2:
  + More work done towards thread-safety.
  + Build fixes on OS.
- Add pkgconfig(glib-2.0) BuildRequires so it can be versioned.
* Mon Sep 10 2012 vuntz@opensuse.org
- Drop pango64.patch:
  + pango-querymodules now has a --update-cache option that will
    update a pango.modules file under %%{_libdir}. This means we no
    longer need to differentiate the 64bit file since it's by
    definition in a different directory.
  + Use this --update-cache option instead of redirecting the
    output of pango-querymodules in the scriplets, in the macros we
    define in macros.pango, and in baselibs.conf.
  + Touch %%{_libdir}/pango/%%{pango_binary_version}/pango.modules in
    %%install instead of %%{_sysconfdir}/pango/pango.modules: this is
    the new file listing the modules.
  + Update README.SuSE accordingly.
  + As a side-effect, this fixes bnc#346210.
* Sun Sep  9 2012 zaitor@opensuse.org
- Update to version 1.31.1:
  + The module cache file can now be located in libdir.
  + Initial work towards making pango thread-safe.
  + Update to Unicode 6.1.
  + Deprecate a few API.
  + Bugs fixed: bgo#682421, bgo#678721, bgo#678997, bgo#653347,
    bgo#682952.
- Rebased pango64.patch.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 1.31.0:
  + Port to harfbuzz 0.9.x, use external harfbuzz
  + Remove Arabic, Hangul, Hebrew, Khmer, Syriac, Tibetan and Thai
    shapers (replaced by harfbuzz)
  + Remove Indic module (replaced by harfbuzz)
  + Remove Atsui support (superseded by CoreText)
  + Remove PangoX
  + Bugs fixed: bgo#679654, bgo#680965, bgo#681423.
- Drop pango-implicit.patch: fixed upstream.
- Add pkgconfig(harfbuzz) BuildRequires: new dependency.
- Bump pango_binary_version defines to 1.8.0 (in baselibs.conf
  too).
* Wed Jun  6 2012 dimstar@opensuse.org
- Update to version 1.30.1:
  + Update Arabic joining classes to 6.1.0
  + Build fixes
  + Annotation fixes
  + Bugs fixed: bgo#667960, bgo#673497, bgo#675400.
- Add pango-implicit.patch: Fix implicit declaration of
  pango_config_key_get_system.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 1.30.0:
  + bgo#667799: Fix cross-compiling bug in configure.in
  + bgo#664125: Zero-width spaces cause missing characters
  + CoreText backend:
  - implement font fallbacks
  - make more robust against broken fonts
  - make shaping engine more robust
  - Guard against glyph count of zero
  + Win32 build fixes
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib files into typelib-1_0-Pango-1_0 subpackage.
- Add typelib-1_0-Pango-1_0 Requires to devel subpackage.
* Tue Nov 22 2011 dimstar@opensuse.org
- Update to version 1.29.5:
  + Documentation fixes
  + Build fixes for ATSUI backend
  + Add more Chinese poetry
  + Fix ChanContext backtrack matching with GPOS
  + Bugs fixed: bgo#653985, bgo#635399, bgo#658561, bgo#656014,
    bgo#654689, bgo#403499, bgo#650456, bgo#653985, bgo#661612.
* Thu Sep 29 2011 vuntz@opensuse.org
- Update to version 1.29.4:
  + Prevent a crash when hitting the fallback engine (bgo#660360)
* Thu Jun 16 2011 vuntz@opensuse.org
- Update to version 1.29.3:
  + Minor fix in 1.29.1 tarball
- Changes from version 1.29.1:
  + Lots of introspection markup added
  + Misc fixes
- Drop pango-no-G_CONST_RETURN.patch: fixed upstream.
* Thu Jun 16 2011 vuntz@opensuse.org
- Add Url tag.
- Change Obsoletes for pango-doc from <= to < to avoid rpmlint
  warning. This is safe as we've updated to new versions several
  times since removing pango-doc.
* Wed Jun 15 2011 dimstar@opensuse.org
- Add pango-no-G_CONST_RETURN.patch: Do not use G_CONST_RETURN,
  patch taken from upstream git (commit 4c7807da).
* Mon May  2 2011 vuntz@opensuse.org
- Fix %%pango_module_post/%%pango_module_postun to create the right
  file (pango.modules instead of pango.immodules).
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 1.28.4:
  + Various introspection annotation fixes
  + Build fixes
  + Require glib >= 2.24.0
  + Bugs fixed:
  - bgo#636348: Hex boxes are incorrectly scaled with non
    identity cairo scale.
  - bgo#639882: Heap corruption in font parsing with FreeType2
    backend.
- Update Obsoletes on library package (from <= to < ).
- Drop pango-CVE-2011-0064.patch and pango-CVE-2011-0020.patch:
  fixed upstream.
* Mon Feb 28 2011 vuntz@opensuse.org
- Add pango-CVE-2011-0020.patch: fixes heap corruption in font
  parsing with FreeType2 backend. Fix bnc#666101, CVE-2011-0020.
- Add pango-CVE-2011-0064.patch: handle realloc failure in the
  buffer to fix potential crashes. Fix bnc#672502, CVE-2011-0064.
* Wed Oct 13 2010 vuntz@opensuse.org
- Do not call pango-querymodules twice in the %%post of
  libpango-1_0-0. Especially since the first call might fail since
  it's not in the if test.
- Put comments that are in the scriptlets area of the spec file in
  "%%if 0" statement: if we don't do that, they actually end up in
  the scriplets and can even make them fail if the scriptlets were
  just "-p /sbin/ldconfig".
* Mon Oct 11 2010 vuntz@opensuse.org
- Update packaging to use the shared library packaging policy:
  + Create libpango-1_0-0 and pango-tools subpackages.
  + Add pango-tools Requires to libpango-1_0-0 for the call to
    pango-querymodules in %%post.
  + Make libpango-1_0-0 Provides/Obsoletes pango.
  + We need %%post/%%postun scriptlets for libpango-1_0-0 and
    pango-tools that call pango-querymodules when possible.
  + Update baselibs.conf accordingly, and simplify it a bit.
- Add RPM macros (macros.pango) to make it easier to handle
  installation of a Pango module.
- Add pango-tools Requires to pango-module-thai-lang for the call
  to pango-querymodules in %%post/%%postun.
- Add pango-module-thai-lang to baselibs.conf, since people want
  the 32-bit module if they have the 32-bit library.
- Update summaries and descriptions.
- Use a find to remove .la files.
- Use <prefix> in baselibs.conf since we use full paths there, and
  this is needed for x86 packages that put files in
  /emul/ia32-linux.
* Wed Sep 29 2010 vuntz@opensuse.org
- Update to version 1.28.3:
  + bgo#630857: introspection: Use --include-uninstalled
- Changes from version 1.28.2:
  + Reduce DLL hijack risk and simplify code in basic-win32 module
  + Improve performance on Windows especially for non-Latin scripts
  + Bugs fixed: bgo#628497, bgo#626966, bgo#629632, bgo#625807
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Sat Aug  7 2010 vuntz@opensuse.org
- Update BuildRequires to use the pkgconfig() style: use cairo,
  fontconfig, freetype2, gobject-2.0, gobject-introspection-1.0,
  libthai, xft, xrender instead of old-style BuildRequires
  (cairo-devel, glib2-devel, gobject-introspection-devel,
  libthai-devel)
- Remove check for old versions of openSUSE (11.0 and earlier).
* Mon Jul  5 2010 dimstar@opensuse.org
- Update to version 1.28.1:
  + pango-view now accepts --margin
  + Various HarfBuzz bug fixes
  + Build fixes
  + Bugs fixed:
  - bgo#582698: Support CSS-style margin specification
  - bgo#621612: VPATH build fix
  - bgo#605870: Incorrect shaping for Syriac
  - bgo#457990: font metrics are not converted to user space in
    cairo backend
  - bgo#613015: [HB] Does not sanitize Device tables referenced
    from ValueRecords.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 1.28.0:
  + [HB] Fix leak when duplicating blob
  + Misc bug fixes
  + Bugs fixed:
  - bgo#611033 - Layout using ATSUI fontmap treats absolute font
    sizes a...
  - bgo#605655 - Pango 1.26.2 introduces kerning bug
  - bgo#611229 - Pango reads from uninitialized memory
  - bgo#594101 - [Indic] needed character class data updates to
    support unicode 5.1
  - bgo#345066 - backspace changes independent indic characters
  - bgo#609326 - Complex script shaping failed in the FT2 backend
    on Windows
  - bgo#604128 - Applications crash when displaying Hebrew
    characters
  - bgo#608923 - Incorrect/broken ligatures on MacOS
  - bgo#610791 - checks fail for unused documented symbols
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 1.27.1:
  + Enable introspection again
  + Misc HarfBuzz bug fixes
  + Improve PangoLayout line breaking
  + Revert usage of CoreText in ATSUI backend
  + Fix FT_Face finalizer call
  + Bugs fixed:
  - bgo#593240 - (pangoosx) Crash / infinite loop with Mac OS X
  - bgo#610183 - Pango doesn't compile with gcc 3.3.3
  - bgo#582697 - Add pango-view --pixels option
* Wed Dec 16 2009 jengelh@medozas.de
- Add baselibs.conf as a source
- Add baselibs for SPARC
* Tue Dec 15 2009 vuntz@opensuse.org
- Update to version 1.26.2:
  + Fix non-standard C++ usage
  + Fix OpenType mark ligation
  + OS X bug fix
  + bgo#602823 - void function cannot return value
  + bgo#602660 - [HB] don't use flexible arrays
  + bgo#602408 - Invalid C++ code breaks compile with Sun C++
    Compiler
* Mon Nov 30 2009 dimstar@opensuse.org
- Update to version 1.26.1:
  + [HB] Fix lookup_flag ignoring
  + Fix leak with non-mmapped fonts
  + Allow using uninstalled glib
  + bgo#341481 - pangocairo kerning problem with nonidentity
    scaling
  + bgo#587768 - Don't build pango-view twice
  + bgo#594101 - character class data updates to support unicode
    5.1
  + bgo#596837 - Typo in pango_cairo_show_layout documentation
* Wed Sep 23 2009 lmedinas@opensuse.org
- Update to version 1.26.0:
  + bgo#595539 - Regressions in rendering certain Thai sequences
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 1.25.6:
  + Fix a couple of array overflow bugs
  + Bugs fixed:
  - bgo#593240 - updating pango to latest git master makes things
    crash
  - bgo#593231 - < c99 compiler dislikes ValueRecord
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 1.25.5:
  + Minor HarfBuzz code shuffling
  + Bugs fixed:
  - bgo#592484 - invalid write in HB
  - bgo#592194 - Fix missing _SC_PAGE_SIZE macro
* Tue Aug 18 2009 dominique-obs@leuenberger.net
- Update to version 1.25.4:
  + Fix various possible overflows in HarfBuzz
  + Improve HB font sanitizing
  + Improved win32 performance
  + Really fix ming32 build issues
  + Re-enable introspection
  + Bugs fixed:
  - bgo#592131 - Add AM_SILENT_RULES
  - bgo#592036 - integer overflow bug causes misrendering of
    Nepali characters
  - bgo#591511 - hh-blob.c does not compile using mingw on
    windows
* Thu Aug 13 2009 vuntz@novell.com
- Update to version 1.25.3:
  + Fix couple of crashers
  + Enforce -fno-exceptions better, should fix build issues for
    distros on x86-64.
  + Call mprotect() only when available.
  + New public API: pango_glyph_item_get_logical_widths()
  + Remove G_GNUC_PURE attr from pango_glyph_string_get_width()
  + Fix buffer corruption in HarfBuzz
  + Bugs fixed:
  - bgo#591413 - needs to link with libstdc++
  - bgo#591511 - hb-blob.c does not compile using mingw on
    windows
  - bgo#591557 - [HB] crash scrolling the evolution message list
  - bgo#591576 - crashed with SIGSEGV at pango
  - bgo#591465 - Gimp crashes upon opening the font selection
    dialog
* Wed Aug 12 2009 vuntz@novell.com
- Update to version 1.25.2:
  + Tweak C++ compiler options. If you get link errors with gcc on
    x86-64 about __gxx_personality_v0(), make sure your CXXFLAGS
    does not have -fexceptions. This will be fixed in Pango itself later.
  + Fix crasher with gzipped fonts. (bgo#591409)
* Mon Aug 10 2009 vuntz@novell.com
- Update to version 1.25.1:
  + Merge harfbuzz-ng: brand new OpenType Layout engine
  + Port to ATSUI backend to use CoreText instead of ATS
  + New public API:
  - pango_gravity_get_for_script_and_width()
  + Misc bug fixes
  - bgo#590042 - pango-view.1 manpage should not be gzipped
  - bgo#410169 - gravity problem with Common chars
  - bgo#589113 - Some characters rotated incorrectly in vertical
    text
  - bgo#582851 - Little fix for compiling with Cygwin
  - bgo#588060 - Fonts missing on Cygwin
* Tue Jul 21 2009 vuntz@novell.com
- Update to version 1.24.5:
  + Build introspection again
  + bgo#589133 - Firefox 3.5 complains about invalid weak
    references
  + bgo#585806 - crash during pango_fc_font_map_shutdown
  + bgo#588678 - pango crash: install a new theme from
- Add gobject-introspection-devel BuildRequires.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 1.24.4:
  + bgo#586814 - Crashes related to fontmap destruction after
    upgrade
* Mon Jun 22 2009 dominique-obs@leuenberger.net
- Update to version 1.24.3:
  + bgo#585337 - Fails to install: install: will not overwrite
    just-created
  + bgo#585164 - 'man preload' shows man page for pango-view
  + bgo#584328 - Persian sample text is not good
  + bgo#583250 - pango_font_metrics_get_approximate_char_width is
    wrong when LANG=fa_IR
* Tue Jun 16 2009 vuntz@novell.com
- Update pango64.patch to also patch Makefile.in, and drop
  autoreconf call: patching Makefile.in is simpler.
* Tue May  5 2009 vuntz@novell.com
- Update to version 1.24.2:
  + bgo#580987 – SIGFPE in pango_glyph_string_index_to_x
  + bgo#580273 – Font metrics functions incorrectly listed as
    reporting point sizes
  + bgo#579694 – Cygwin parallel-build patch
  + bgo#578944 – pango-1.24.1 fails its testsuite
  + bgo#578935 – Syntax error (missing semicolon) in
    pango/pangowin32-fontmap.c
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 1.24.1:
  + Fix a couple of crashers
  + Fix minor pangofc API semantics breakage
  + Better handle SFNT fonts in dfont containers
  + Improved docs
  + Improved Indic shaper for new Unicode 5.1 characters
  + Misc bug fixes
  + Bugs fixed in this release:
  - bgo#577952 – Error loading {GDEF,GSUB,GPOS} table 0x6EAD
  - bgo#578336 – ABI breakage from 1.22 to 1.24 in fontmap field
    of PangoFcFont
  - bgo#556132 – gnome-panel crashed with SIGSEGV in
    g_cclosure_marshal_VOID__BOXED()
  - bgo#571291 – Unicode 5.1 support in pango - Indic Lanuages
  - bgo#576298 – Fails to link pango-view if --without-x is
    specified but cairo has X11 support
* Tue Mar 17 2009 mboman@suse.de
- Update to version 1.24.0:
  + pango-view improvements:
  * pango-view -q now works without a X server
  * Ability to save to PS, EPS, PDF, and SVG files.  Filetype is
    detected from output file extension
  * New options --foreground, --background, and --annotate
  * Now installs a manual page, thanks to help2man
  + PangoFc API changes:
  * PangoFcFont now has a "fontmap" property that subclasses can
    use at construction time to setup the font->fontmap link
  * New backend-public API:
    o pango_fc_font_map_find_decoder()
  + Misc optimizations
  + Build fixes
  + Misc bug fixes
  + Bugs fixed in this release:
  * bgo#547963 - man page for pango-view
  * bgo#502804 - pango-view or pangocairo-view option to
    annotate
  * bgo#502801 - per-backend pango-view options
  * bgo#502805 - pango-view option for foreground/background
    color
  * rh#490331  - Crash of galeon in libpango
  * bgo#523166 - pango-view opens display even when invoked with
  - q
  * bgo#567160 - Share cmap cache between PangoFcFont's of the
    same face
  * rh#487593  - crash changing language in gdm
  * bgo#572662 - Remove deprecated GTK+ symbols
  * bgo#572529 - Poor -I ordering can break build
- Remove perl-XML-Parser and sgml-skel from BuildRequires
- Remove AutoReqProv since it's default
- Remove %%if statements <= 1020
- Remove xorg-x11-libs from PreReq
- Remove glibc-devel from Requires in -devel package
- Merge -doc into -devel since it only contained gtk-doc
- Remove custom CFLAGS
* Thu Feb  5 2009 mboman@suse.de
- Update to version 1.23.0:
  + Change the PangoFc font loading API to allow for lazy loading
    of fonts.
  + Add private PangoFcFontset that loads fallback fonts as needed
  + Call FcFontMatch() and only if fallback fonts are needed call
    FcFontSort().
  + Optimize HarfBuzz number of malloc calls
  + Don't malloc megs of unused memory in HarfBuzz
  + Print-out, and parse, numeric styles correctly. Things like
    "DejaVu Sans weight=100" parse as font description now.
  + New public API:
  * PANGO_ATTRIBUTE_INDEX_FROM_TEXT_BEGINNING
  * PANGO_ATTRIBUTE_INDEX_TO_TEXT_END
  * PANGO_WEIGHT_BOOK
  * PANGO_WEIGHT_ULTRAHEAVY
  * PANGO_WEIGHT_THIN
  * PANGO_WEIGHT_MEDIUM
  + Bugs fixed: bgo#569763,bgo#560792, bgo#567392, bgo#566727,
    bgo#567165, bgo#567934, bgo#549532, bgo#566726, bgo#566941,
    bgo#551469, bgo#328206, bgo#166709, bgo#166676, bgo#164001,
    bgo#384362, bgo#168085, bgo#529591, bgo#515807, bgo#512662,
    bgo#565644, bgo#469049, bgo#565379, bgo#564877
* Wed Jan 28 2009 vuntz@novell.com
- Drop pango-libtool.patch: it's already included upstream.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Dec 24 2008 mboman@suse.de
- Update to version 1.22.4:
  + Misc bug fixes
  + Improved docs
  + Bugs fixed in this release:
  - bgo#564644 – Not complete description of the
    pango_font_description_better_match function
  - bgo#563898 – Generated output is not deterministic
  - bgo#563803 – pango_renderer_finalize fails to call parent finalize
  - bgo#499626 – Space should be optional after comma in
    PangoFontDescription input string
  - bgo#499624 – Spaces around commas in PangoFontDescription family name
    should be trimmed
  - bgo#563557 – set g_get_prgname() in fc pattern
  - bgo#563356 – The input area of firefox and the blank width after text
    in gnome-menu was stretched too wide, under pango-1.22.3
  - bgo#562574 – Pangocariowin32 is leaking every cairo font it ever
    creates
* Mon Dec  8 2008 mboman@suse.de
- Update to version 1.22.3:
  + bgo#561740 – Use stack allocation for thai_engine_break
  + bgo#561779 – incorrect calculations in pango_matrix_concat
    implementation
  + Bgo#560730 – pango 1.22.2 build failure on Solaris 10, too many array
    initializers in pango-language.c
  + Write error code in capital hex.
  + Bgo#558254 – Internal reference handling messed up
  + bgo#558107 – is_monospace always returns FALSE in pangoatsui
  + bgo#557620 – pango_font_description_from_string not correct
* Tue Nov 11 2008 ro@suse.de
- SLE-11 uses PPC64 instead of PPC, adapt baselibs.conf
* Wed Oct 22 2008 mboman@suse.de
- Update to version 1.22.1:
  - Fix crasher when freeing PangoLayoutIter's
  - Fix loading of bogus OpenType anchor tables
  - Fix OpenType CursiveChain positioning
  - Bugs fixed: bgo#528272, bgo#552107, bgo#539623, bgo#555219, bgo#553345
* Tue Oct  7 2008 sbrabec@suse.cz
- Call pango-querymodules for thai-lang module (bnc#431518).
* Tue Oct  7 2008 cthiel@suse.de
- Update to version 1.22.0:
  + Improved Romanian sample text
  + Misc bug fixes
  + Bugs fixed (by number): bgo#552993, bgo#551865, and bgo#551416.
* Sun Sep 28 2008 ro@suse.de
- add gcc-c++ to buildrequires to work around libtool problem
* Wed Sep 10 2008 maw@suse.de
- Update to version 1.21.6:
  + Improve language sample strings
  + Bugs fixed: bgo#550659, bgo#549758, bgo#549522, and bgo#549520.
* Sat Aug 30 2008 mboman@novell.com
- Updated to version 1.21.5:
  + Make the reference the font->fontmap reference weak.
  + Improve pango_language_get_sample_string() to add language sample texts
    that are actually usable.
  + In pango_language_get_sample_string() use default language if provided
    language is NULL.
  + Update OpenType language-system tags to OpenType 1.5 draft intersected
    with ISO639-3 of 2008/08/04.
  + New API addition.
  + Bugs fixed: bgo#549003, bgo#143542, bgo#314094, bgo#473806,
    bgo#473805, bgo#470895, bgo#547432
* Sun Aug 24 2008 mboman@novell.com
- Updated to version 1.21.4:
  * Bugs fixed: bgo#547303, bgo#546534, bgo#431394, bgo#377948,
    bgo#377948, bgo#472625, bgo#472625, bgo#472625, bgo#540592,
    bgo#540036, bgo#380094, bgo#536017, rh#457883
  * Various fixed and new API's. See ChangeLog for complete
    details.
* Tue Jul 29 2008 sbrabec@suse.cz
- Do not build thai-lang module for older products.
* Fri Jul 18 2008 vuntz@novell.com
- Tag pango64.patch
* Tue Jul  8 2008 crrodriguez@suse.de
- fix build
* Wed Jun 18 2008 maw@suse.de
- Update to version 1.21.3:
  + Various small fixes and improvements
  + Bugs fixed: bgo#538661, bgo#536190, bgo#537258, bgo#537257,
    and bgo#537186.
* Mon Jun  9 2008 maw@suse.de
- Update to version 1.21.2:
  + Require cairo >= 1.6.4
  + Write out HarfBuzz errors as hex.
  + Add a section in the docs for bidirectional text.
  + Improved hex-box rendering in the cairo backend.
  + Add some aliases for <span> tag attributes.
  + Preserve current-point around pango_cairo_* functions.
  + Partial work to make pango_break() exactly follow Unicode TR#14
    and TR#29; the Grapheme Boundaries and Word Boundaries now work;
    for word boundaries; a new member was added to PangoLogAttr;
    sentence Boundaries and Line Breaks to follow in the next
    release
  + Err if no cairo font backends found
  + Misc bug fixes
  + New public API:
  * pango_attr_type_get_name()
  * enum PangoBidiType;
  * pango_bidi_type_get_type()
  * pango_bidi_type_for_unichar()
  * pango_layout_get_baseline()
  * pango_cairo_create_context()
  * pango_cairo_font_map_set_default()
  * New PangoLogAttr member, is_word_boundary, that implements
    UAX#29's Word Boundaries semantics; the is_word_start and
    is_word_end members will change implementation later on to
    be consitent with the word boundaries
  + Bugs fixed: bgo#515432, bgo#517119, bgo#404416, bgo#474706,
    bgo#490669, bgo#501334, bgo#514617, bgo#511183, bgo#531242,
    bgo#530757, bgo#530685, bgo#97545 (partial), bgo#510299,
    bgo#436363, and bgo#523193.
* Wed May 21 2008 sbrabec@suse.cz
- Enabled optional thai-lang module (bnc#326002).
- Fixed devel dependencies.
* Wed May  7 2008 olh@suse.de
- execution failure of pango-querymodules-64 on 32bit systems is
  not fatal (bnc#301792)
* Tue May  6 2008 schwab@suse.de
- Don't use libtool before it is created.
* Fri Apr 11 2008 maw@suse.de
- Tag pango-libtool.patch, which was added in the previous
  submission.
* Fri Apr 11 2008 schwab@suse.de
- Work around broken configure script.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 maw@suse.de
- Update to version 1.20.1:
  + Update to Unicode Character Databse 5.1.0; this adds newentries
    to the PangoScript enum
  + Try making our OS X stuff compile with latest cairo 1.5.x
    snapshots that renamed cairo-atsui to cairo-quartz-font, as well
    as older versions
  + Minor bug fixes.
* Fri Mar 14 2008 maw@suse.de
- Update to version 1.20.0:
  + Bug fixed: bgo#518084.
* Mon Mar  3 2008 maw@suse.de
- Update to version 1.19.4:
  + Fixed blocker bug with pango_layout_set_height() and positive
    height
  + Fixed small leak in ATSUI backend
  + Improved docs
  + Bugs fixed: bgo#511172, bgo#515484, bgo#515484, bgo#517083,
    bgo#515484, bgo#504810, bgo#496244, bgo#512566, and bgo#512473.
* Thu Jan 31 2008 maw@suse.de
- Update to version 1.19.3:
- pango_layout_get_pixel_extents() and pango_layout_line_get_pixel_extents()
  now round extents to pixels inclusively.  That is, pass both ink_rect and
  logical_rect as first argument to pango_extents_to_pixels().
- Rename pango_extents_to_pixels() function arguments from @ink_rect and
  @logical_rect to @inclusive and @nearest.  Given that this API is a
  fairly new addition and not commonly used, language bindings are
  encouraged to update their argument names accordingly.  Moreover, they
  are encouraged to wrap this function as two different calls:
  extents_to_pixels_inclusive() and extents_to_pixels_nearest(), or
  similar conventions that best reflect their native language.
- HarfBuzz was relicensed to a more generous and simpler license.
  Adapt.  See pango/opentype/COPYING for the new license which is
  LGPL-compatible.
- New public API:
  pango_layout_set_height()
  This sets the height to which the #PangoLayout should be ellipsized at.
  There are two different behaviors, based on whether @height is positive or
  negative.
  If @height is positive, it will be the maximum height of the layout.  Only
  lines would be shown that would fit, and if there is any text ommitted, an
  ellipsis added.  At least one line is included in each paragraph regardless
  of how small the height value is.  A value of zero will render exactly one
  line for the entire layout.
  If @height is negative, it will be the (negative of) maximum number of lines
  per paragraph.  That is, the total number of lines shown may well be more
  than this value if the layout contains multiple paragraphs of text.  The
  default value of -1 means that first line of each paragraph is ellipsized.
  Height setting only has effect if a positive width is set on @layout and
  ellipsization mode of @layout is not %%PANGO_ELLIPSIZE_NONE.
  The behavior is undefined if a height other than -1 is set and ellipsization
  mode is set to %%PANGO_ELLIPSIZE_NONE, and may change in the future.
  There are still bugs remaining to be fixed, notably bug 511172 (which will
  be fixed before 1.20), and bug 511171 (which will be fixed in a future
  version).
- New command-line arguments to pango-view: --height and --single-par.
- Make the following symbols available to engines:
  PANGO_IS_OT_INFO
  PANGO_IS_OT_RULESET
  PANGO_OT_INFO
  PANGO_OT_RULESET
  PANGO_TYPE_OT_INFO
  PANGO_TYPE_OT_RULESET
  pango_ot_info_get_type
  pango_ot_ruleset_get_type
- Bugs fixed in this release:
  bgo#508002 – change pango_layout_pixel_extents() to round logical rect
  to be inclusive
  bgo#469313 – Add pango_layout_set_height()
  bgo#508179 – PangoGlyphUnit confusion
  bgo#508381 – indent and center alignment don't mix
  bgo#508007 – Add option for single-paragraph mode to pango-view
  bgo#506284 – docs typo for pango_coverage_unref
  Patch from Christian Persch
  bgo#504802 – build failure: No rule to make target
  `pango-querymodules.1', needed by `all-am'. Stop.
  bgo#504585 – pango-querymodules.1 syntax error
  brc#426178: gtkdoc-scan fails on pango
* Thu Dec 20 2007 maw@suse.de
- Revert to using pango64.patch for the time being (#349940).
* Mon Dec 17 2007 maw@suse.de
- Remove references to README.SuSE
- s#%%run_ldconfig#/sbin/ldconfig#.
* Mon Dec 17 2007 maw@suse.de
- Replace pango64.patch with pango-biarch.patch (#346210)
- Concomitant with the above change, remove README.SuSE, as it is
  no longer necessary.
* Mon Dec 17 2007 maw@suse.de
- Update to version 1.19.2:
  + Bugs (bugzilla.gnome.org) fixed: #485536, #500549, #492517,
    [#495091], #502926, #399573, #478914, #501938, and #501575
  + Cleanups in the HarfBuzz code and merges with upstream/Qt changes
  + Document cairo examples and misc doc improvements
  + Use pkg-config to detect cairo features
  + New public macro: PANGO_GLYPH_INVALID_INPUT
  + Render a crossed box for each invalid input byte to
    pango_layout_set_text; previously an ASCII question mark was
    used; this crossed box has a glyph of value
    PANGO_GLYPH_INVALID_INPUT.
* Mon Nov 26 2007 maw@suse.de
- Actually remove the build root in %%clean.
* Fri Nov 23 2007 maw@suse.de
- Update to version 1.19.0:
  + Two OpenType engine fixes, which make Nafees Nastaliq font
    work great, and avoids warnings with some other fonts
  + Fix minor leak in win32 backend
  + Update list of languages to that of fontconfig-2.4.91
  + Various optimizations
  + Make sure all boxed type copy/free functions accept NULL as
    legitimate input; previously most were g_return_[val_]if_fail()ing
    it; this is mostly for convenience when writing code in C
  + Apply 'vkrn' GPOS feature in vertical writing
  + In pangofc, set "pangoversion" in pattern passed to fontconfig,
    such that font configuration can condition on being driven by
    Pango or not
  + Various optimizations and cleanups in the OpenType Layout
    engine, aka HarfBuzz
  + Changed APIs:
  * All PangoAttribute constructors are changed to initialize
    the attribute to the range [0..MAXUINT].  The range was
    undefined previously; all custom attribute constructors
    are recommended to call the new pango_attribute_init() to
    do the same
  * Public API change: Mark the following types as abstract:
    PangoFont
    PangoFontFace
    PangoFontFamily
    PangoFontMap
    PangoFcFont
    PangoFcFontMap
    PangoContext may be marked so in the future too
  * Make following macros public; previously they were only
    defined for backend/engine implementations:
    PANGO_GLYPH_EMPTY
    PANGO_GLYPH_UNKNOWN_FLAG
    PANGO_GET_UNKNOWN_GLYPH()
  + New public API:
  * Convenience for initializing custom attributes:
    pango_attribute_init()
  * Adding boxed type for PangoGlyphItem:
    PANGO_TYPE_GLYPH_ITEM
    pango_glyph_item_copy()
    pango_glyph_item_get_type()
  * Add missing copy function for a boxed type in C:
    pango_layout_iter_copy()
  * Add missing getter:
    pango_layout_iter_get_layout()
  * Convenience for writing custom PangoRenderer's:
    pango_renderer_get_layout()
    pango_renderer_get_layout_line()
  * PangoFc extensions to fontconfig's pattern syntax:
    PANGO_FC_GRAVITY
    PANGO_FC_VERSION
  + Bugs (bugzilla.gnome.org) fixed: #483600, #490661,
    [#489909], #488840, #486932, #486951, #485621, #485566,
    [#485559], #481537, #478865, #472924, #472629, #472303,
    [#471601], #471577, #471571, #471568, and #469641.
* Tue Sep 18 2007 maw@suse.de
- Add xorg-x11-libXdmcp as a prerequisite (#310640)
- Fix the source tarball's permissions.
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 1.18.2:
  * require libthai >= 0.1.9 for enabling thai-lang module
  * bug fixes
* Wed Aug 29 2007 maw@suse.de
- Update to version 1.18.1:
  + Make pango_script_for_unichar() just call
    g_unichar_get_script() and document that PangoScript and
    GUnicodeScript are interchangeable enumerations
  + Bug fixes, including the following (bugzilla.gnome.org):
    [#470042], #468953, #463430, #348348, #451682, #462137, #462420,
    [#462630], #464183, #464270, #465174, #466755, #467056, and
    [#467077],
- Remove upstreamed pango-1.17.4-empty-string-corruption.patch.
* Tue Jul 31 2007 maw@suse.de
- Update to version 1.17,5
- Export PangoCairoFont and cleanup various standard macros
- Bugs (bugzilla.gnome.org) fixed: #150883, #449482, and part of
  [#347236].
* Tue Jul 31 2007 jpr@suse.de
- Fix memory corruption for empty line break call (#295662)
- Remove references to patch that no longer exists
* Thu Jul 26 2007 maw@suse.de
- Update to version 1.17.4
- Refactored the ATSUI font backend and install pangoatsui.h
  that has a single function pango_atsui_font_get_atsu_font_id() and
  a couple of types.
- Bugs [bugzilla.gnome.org] fixed in this release:
  Bug 451547 – FAIL: runtests.sh
  Bug 449543 - Ship pangoatsui.h
* Thu Jul  5 2007 maw@suse.de
- Update to version 1.17.3
- Extensive pangocairo internal code refactoring and cleanup
- New public API, new engine macros
- Many bugfixes.
* Wed Apr 11 2007 maw@suse.de
- Update to version 1.16.2
- Fixed various bug in the OpenType Layout code (HarfBuzz)
- Improved documentation
- Improved ATSUI backend
- Misc build system fixes
- Bugs fixed in this release:
  * Bug #417946 - pangowin32-fontmap.c:using function without prototype
  * Bug #419262 - Don't create coverage every time it's asked for
  (Both of these bugs are viewable at bugzilla.gnome.org)
- Refresh pango64.patch.
* Wed Mar 21 2007 maw@suse.de
- Update to version 1.16.1
- Fixes for b.g.o #120195, #407315, #355987, and #407087.
* Fri Feb 16 2007 maw@suse.de
- Update to version 1.15.6
- Remove bugzilla-53228-artificial-bold-and-italic.patch, which
  is now upstream.
* Wed Jan 17 2007 sbrabec@suse.cz
- Use correct library instance in scriptlets (#235626).
* Thu Dec  7 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Mon Nov 27 2006 sbrabec@suse.cz
- Use correct PreReq for older products.
* Thu Nov 23 2006 sbrabec@suse.cz
- Fixed scriptlets for bi-arch (#223149).
* Sat Oct 14 2006 danw@suse.de
- Remove dead patch
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 1.14.5
- Indic shaper fixes
- Misc bug fixes
* Sun Sep 17 2006 ro@suse.de
- added prereqs for postinstall script
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 1.14.3
- Win32 build improvement
- Bug 353525 ¿ libpangoft2-1.0.so.0: undefined reference to
  `pango_font_description_get_gravity'
- Bug 349813 ¿ typo in docs for pango_layout_move_cursor_visually
* Mon Sep  4 2006 sbrabec@suse.cz
- Removed SuSEconfig.pango (FATE#300947).
* Tue Aug 29 2006 jhargadon@suse.de
- update to version 1.14.2
- Find shaper/font for Private Use and space characters
* Thu Aug 17 2006 jhargadon@suse.de
- update to version 1.14.0
- Make pango-view accept non-ASCII --text
- Require cairo-1.2.2 for the important bug fixes it has.
* Mon Jul 31 2006 gekker@suse.de
- Update to version 1.13.4
  * Update to Unicode Character Database 5.0.0.
  * Misc fixes.
  * Bugs fixed in this release:
    Bug 336282 Ð Update to Unicode Character Database 5.0.0
    Bug 347073 Ð Allow empty GPOS table
    Bug 347021 Ð atsui crash when a matching font cannot be found.
    Patch from Brian Tarricone.
* Fri Jul 28 2006 gekker@suse.de
- Update to version 1.13.3
- Remove upstreamed patches
  * New public API:
  - pango_glyph_string_get_width
  * Improved hexbox drawing, and font metrics calculations.
  * New public API:
  - pango_cairo_show_error_underline
  - pango_cairo_error_underline_path
  - pango_font_describe_with_absolute_size
  * Increased robustness against broken pango.modules
  * Fix incorrect rendering when in x86 64-bit precision mode
  * Fix non-OpenType fonts losing kerning in 1.12.0 [#336026, Denis Jacquerye]
  * Moved the OpenType Layout code into a new project called HarfBuzz
  * Insert '?' chars instead of invalid UTF-8 sequences in
    pango_layout_set_text [#33195]
  * Fix a few crashers, especially when a font cannot be read. [#314239]
  * Change some g_critical's to g_warning, where it's not application's
    fault. [#331723]
  * Major change in the low-level interface of Pango.  The special value
    PANGO_GLYPH_EMPTY is now defined to mean a "draw nothing" glyph.  This
    was what glyph 0 was used for previously.  As a result, bumped up the
    Pango module version, meaning that modules compiled against earlier
    versions are probably not compatible with this release. [#73147]
  * New framework in examples for building a binary called pango-view,
    that can be used to render a text file using any of the available
    backends.  This is installed into bindir now.
  * Enhancements to the FT2 backend, to draw boxes on missing glyphs.
  * Better hexbox drawing for cairo backend:  Hinting hexbox, and
    drawing a single-row hexbox for very small font sizes.
  * Do not crash if the shapers fail.
  * Draw hex box on missing glyphs for cairo-fc backend.
  * New --with-dynamic-modules option added to configure.
  * ATSUI support for the cairo backend. [Anders Carlsson]
  * Draw a dashed empty box on missing glyphs for cairo-fc backend.
  * Support OpenType features for basic (Latin/Greek/...) module.
  * Support swash feature in Arabic module.
  * Line-breaking algorithm updated to Unicode 4.1.
  * Code borrowed from GNU FriBidi resynched to version 1.0.7.
* Tue May  2 2006 federico@novell.com
- Added pango-104365-use-hinted-metrics.diff to fix the Pango-related
  part of https://bugzilla.novell.com/show_bug.cgi?id=104365.  This
  makes Pango request hinted font metrics from Cairo/Fontconfig, even
  when we are using unhinted rendering.  This is what applications
  expect; they would draw overlapping glyphs otherwise.
* Mon Apr 24 2006 federico@novell.com
- Added pango-131128-font-extents-rounding.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=131128.  This makes
  PangoCairoFcFont round the font extents before exposing them to
  callers, which produces better results with unhinted /
  un-antialiased displays.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 sbrabec@suse.cz
- Removed libpixman from neededforbuild.
* Fri Dec 30 2005 mfabian@suse.de
- Bugzilla #53228: Enhance pango to support artifical bold and
  italic (add patch by Zhe Su).
* Wed Dec 14 2005 sbrabec@suse.cz
- Added related old version cleanups (feature #2852).
* Wed Nov 30 2005 sbrabec@suse.cz
- Update to version 1.10.2.
* Tue Oct 11 2005 gekker@suse.de
- Update to version 1.10.1
* Thu Aug 18 2005 gekker@suse.de
- Update to version 1.10.0
* Mon Aug  1 2005 gekker@suse.de
- Update to version 1.9.1
* Thu Jul 21 2005 gekker@suse.de
- Update to version 1.9.0
* Thu Jun 23 2005 sbrabec@suse.cz
- Fixed devel dependencies.
- Removed .la files for modules.
* Mon Apr 11 2005 sbrabec@suse.cz
- Fixed Requires of doc subpackage.
* Tue Mar  8 2005 gekker@suse.de
- Update to version 1.8.1 (GNOME 2.10).
* Mon Jan  3 2005 gekker@suse.de
- Update to version 1.8.0
* Wed Dec 15 2004 gekker@suse.de
- Update to version 1.7.0
* Wed Nov 17 2004 gekker@suse.de
- Update version to 1.6.0.
* Wed Oct 20 2004 ro@suse.de
- make specfile rpm-3-save
* Thu Aug 26 2004 federico@ximian.com
- Updated to pango 1.4.1
- Removed pango-strict-aliasing.patch, as an equivalent patch is in
  the tarball now
* Fri May 21 2004 sbrabec@suse.cz
- Added ottest to devel package.
* Tue Apr 27 2004 sbrabec@suse.cz
- Fixed pango64.patch.
* Mon Apr 19 2004 sbrabec@suse.cz
- Strict aliasing fix.
* Thu Apr 15 2004 sbrabec@suse.cz
- Updated to version 1.4.0 (GNOME 2.6).
* Thu Mar 11 2004 sbrabec@suse.cz
- Use SuSEconfig biarch wrapper and identical filename for all
  platforms.
- Include README.SuSE about biarch problems.
* Tue Mar  2 2004 sbrabec@suse.cz
- Bi-arch work-arounds to prevent 32/64 bit conflicts (bug #33705).
  For more see http://bugzilla.gnome.org/show_bug.cgi?id=129534
* Mon Mar  1 2004 sbrabec@suse.cz
- Fixed random crashes of gnome-terminal using mc (bug #29850).
  http://bugzilla.gnome.org/show_bug.cgi?id=89541
- Use run-pango in %%postun, too.
- Build with -fno-strict-aliasing.
* Tue Jan  6 2004 adrian@suse.de
- fix build
* Mon Oct  6 2003 kukuk@suse.de
- Remove unused atk from neededforbuild
* Mon Sep  8 2003 sbrabec@suse.cz
- Removed invalid %%postun.
* Fri Sep  5 2003 sbrabec@suse.cz
- Fixed rmdir in %%postun.
* Fri Sep  5 2003 sbrabec@suse.cz
- Remove orphan files from SuSE 8.2.
* Thu Aug 28 2003 sbrabec@suse.cz
- Updated to version 1.2.5.
* Tue Jul 15 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 12 2003 sbrabec@suse.cz
- Branched pango-doc.
- Updated file list.
- Fixed calling of aclocal.
* Wed Jun 11 2003 sbrabec@suse.cz
- Updated to version 1.2.3.
- Fixed directory packaging.
- Require gnome-filesystem for pango-devel (for docs).
- Updated neededforbuild.
* Mon Apr 28 2003 sf@suse.de
- added fontconfig* to neededforbuild, to compile pangoft2
* Fri Feb 21 2003 hhetter@suse.de
- PreReq touch (Bug Id#23897)
* Mon Feb  3 2003 hhetter@suse.de
- updated to version 1.2.1:
  * Handle older TrueType Open Arabic fonts.
  * Make Win32 backend handle a common TrueType font bug
  * Fix crash with some non-BMP characters
  * Avoid crashing on font descriptions like " 12"
  * Minor build fixes
* Mon Jan 13 2003 sbrabec@suse.cz
- Added expat to neededforbuild (for new xft2).
* Thu Jan  9 2003 sbrabec@suse.cz
- Updated to version 1.2.0.
* Thu Nov  7 2002 hhetter@suse.de
- updated to version 1.0.5
  * Bug fix for pango_scan_int() needed for recent GTK+.
  * Improve language specific charset ordering basic-x11
  * Fix symbols that shouldn't have been exported
  * Some cross-compiling fixes
  * Various build fixes
  * Fix check for no-backend being found.
* Tue Oct 22 2002 sbrabec@suse.cz
- Remove obsolette install -d -m755 $RPM_BUILD_ROOT/var/adm/SuSEconfig.
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Tue Aug 13 2002 hhetter@suse.de
- disabled qt support (#17642)
* Mon Aug  5 2002 hhetter@suse.de
- updated to version 1.0.4, from changes:
  * Add Thai shaper for Xft
  * Support GB-18030, BIG5-HKSCS, CNS-11643, GBK encodings for
  basic-x shaper
  * Support ksc5601.1992-3 fonts in hangul-x shpaer
  * Support new Arabic characters in Unicode 3.2
  * misc Bug fixes
* Mon Jun 17 2002 jordi@suse.de
- Updated to version 1.0.3
  * Change algorithm for mapping points to pixels on
  Windows to match the system method.
  * Fix family listing for the FT2 backend.
  * Fix memory leak in pango_font_real_get_metrics()
  * Some compilation warning fixes.
  * Fix passing attr_list == NULL to pango_parse_markip
* Thu Jun 13 2002 ro@suse.de
- fix autotools sequence
* Wed Jun 12 2002 hhetter@suse.de
- correctly touch the run-pango flag
* Wed Jun 12 2002 hhetter@suse.de
- fix SuSEconfig script
* Tue Jun  4 2002 hhetter@suse.de
- update to version 1.0.2 of the stable series
  * Support building with FreeType 2.1.0
  * List Sans,Serif,Monospace when listing fonts for the
  Xft and FT2 backends.
  * Portability fixes.
  * Fix problem with pango-querymodules using g_print().
* Tue Apr 30 2002 meissner@suse.de
- %%_lib fixes
* Mon Apr 15 2002 hhetter@suse.de
- fix config script to work with correct path
* Tue Apr  9 2002 hhetter@suse.de
- filelist correction
* Tue Apr  9 2002 hhetter@suse.de
- updated to version 1.0.1
* Thu Jan 31 2002 hhetter@suse.de
- updated to version 0.24 [GNOME desktop-alpha2]
* Thu Jan 17 2002 hhetter@suse.de
- delete SuSEconfig-run-flag after registering pango modules
* Wed Jan 16 2002 ro@suse.de
- re-added .so symlinks to devel filelist (without wildcards)
* Wed Jan 16 2002 hhetter@suse.de
- added SuSEconfig script to register the pango modules
- fixed filelist
* Tue Jan 15 2002 hhetter@suse.de
- fixed filelist
* Fri Jan 11 2002 hhetter@suse.de
- updated to version 0.23:
  * Documentation improvements
  * Win32 fixes
  * Improve search for XftConfig
  * Fixes for crashes in Hangul shaper
  * Improvements to Arabic shapers for X and Xft
  * Add jisx0212, jisx0201, Big5 support to basic shaper
* Wed Jan  9 2002 hhetter@suse.de
- enable freetype2 support
* Tue Dec 11 2001 hhetter@suse.de
- really build pangox and pango
* Tue Dec 11 2001 hhetter@suse.de
- added LIBRARY_PATH for broken libtool
* Tue Nov 27 2001 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform (pango 0.22)
